@@ -5,7 +5,7 @@ from os.path import basename
 
 from integration_tests.test_cfngin.test_cfngin import Cfngin
 
-FILE_BASENAME = '.'.join(basename(__file__).split('.')[:-1])
+FILE_BASENAME = ".".join(basename(__file__).split(".")[:-1])
 
 
 class TestSimpleBuild(Cfngin):
@@ -15,41 +15,39 @@ class TestSimpleBuild(Cfngin):
 
     """
 
-    REQUIRED_FIXTURE_FILES = [
-        FILE_BASENAME + '.yaml'
-    ]
+    REQUIRED_FIXTURE_FILES = [FILE_BASENAME + ".yaml"]
     TEST_NAME = __name__
 
     def _build(self):
         """Execute and assert initial build."""
-        code, _stdout, stderr = self.runway_cmd('deploy')
-        assert code == 0, 'exit code should be zero'
+        code, _stdout, stderr = self.runway_cmd("deploy")
+        assert code == 0, "exit code should be zero"
         expected_lines = [
-            'using default AWS provider mode',
-            'simple-build-vpc:submitted (creating new stack)',
-            'simple-build-vpc:complete (creating new stack)'
+            "using default AWS provider mode",
+            "simple-build-vpc:submitted (creating new stack)",
+            "simple-build-vpc:complete (creating new stack)",
         ]
         for line in expected_lines:
             assert line in stderr, f'"{line}" missing from output'
 
     def _update_no_change(self):
         """Execute and assert second build with no changes."""
-        code, _stdout, stderr = self.runway_cmd('deploy')
-        assert code == 0, 'exit code should be zero'
+        code, _stdout, stderr = self.runway_cmd("deploy")
+        assert code == 0, "exit code should be zero"
         expected_lines = [
-            'using default AWS provider mode',
-            'simple-build-vpc:skipped (nochange)'
+            "using default AWS provider mode",
+            "simple-build-vpc:skipped (nochange)",
         ]
         for line in expected_lines:
             assert line in stderr, f'"{line}" missing from output'
 
     def _destroy(self):
         """Execute and assert destroy."""
-        code, _stdout, stderr = self.runway_cmd('destroy')
-        assert code == 0, 'exit code should be zero'
+        code, _stdout, stderr = self.runway_cmd("destroy")
+        assert code == 0, "exit code should be zero"
         expected_lines = [
-            'simple-build-vpc:submitted (submitted for destruction)',
-            'simple-build-vpc:complete (stack destroyed)'
+            "simple-build-vpc:submitted (submitted for destruction)",
+            "simple-build-vpc:complete (stack destroyed)",
         ]
         for line in expected_lines:
             assert line in stderr, f'"{line}" missing from output'
@@ -57,13 +55,13 @@ class TestSimpleBuild(Cfngin):
     def run(self):
         """Run the test."""
         self.copy_fixtures()
-        self.set_env_var('VERBOSE', '1')
+        self.set_env_var("VERBOSE", "1")
         self._build()
         self._update_no_change()
         self._destroy()
 
     def teardown(self):
         """Teardown any created resources and delete files."""
-        self.unset_env_var('VERBOSE')
-        self.runway_cmd('destroy')  # cleanup incase of failure
+        self.unset_env_var("VERBOSE")
+        self.runway_cmd("destroy")  # cleanup incase of failure
         self.cleanup_fixtures()
