@@ -1,4 +1,5 @@
 """Test deploying stacks using tags."""
+# pylint: disable=no-self-use
 import os
 from subprocess import check_output
 
@@ -12,23 +13,19 @@ class TestRunPython(Commands):
 
     def init(self):
         """Initialize test."""
-        pass  # pylint: disable=unnecessary-pass
 
     def run(self):
         """Run tests."""
-        fixtures_path = os.path.join(os.path.dirname(os.path.dirname(__file__)),
-                                     'fixtures')
-        with open(os.path.join(fixtures_path,
-                               'buildpipeline.json'), 'r') as stream:
+        fixtures_path = os.path.join(
+            os.path.dirname(os.path.dirname(__file__)), "fixtures"
+        )
+        with open(os.path.join(fixtures_path, "buildpipeline.json"), "r") as stream:
             expected_template = stream.read()
         generated_template = check_output(
-            ['runway',
-             'run-python',
-             os.path.join(fixtures_path, 'buildpipeline.py')]
+            ["runway", "run-python", os.path.join(fixtures_path, "buildpipeline.py")]
         ).decode()
 
         assert generated_template == expected_template
 
     def teardown(self):
         """Teardown any created resources."""
-        pass  # pylint: disable=unnecessary-pass
