@@ -14,9 +14,9 @@ if sys.version_info.major > 2:
 else:
     from pathlib2 import Path  # pylint: disable=E
 
-LOGGER = logging.getLogger(__name__.replace('._', '.'))
+LOGGER = logging.getLogger(__name__.replace("._", "."))
 ROOT = Path(__file__).parent.parent.parent.parent
-TEMPLATES = ROOT / 'templates'
+TEMPLATES = ROOT / "templates"
 
 
 def convert_gitignore(src):
@@ -29,7 +29,7 @@ def convert_gitignore(src):
         Optional[Path]: The renamed file if it was created.
 
     """
-    gitignore = src.parent / '.gitignore'
+    gitignore = src.parent / ".gitignore"
     LOGGER.debug('renaming "%s" to "%s"', src, gitignore)
     src.rename(gitignore)
     return gitignore
@@ -45,7 +45,7 @@ def copy_sample(ctx, src, dest):
 
     """
     if dest.exists():
-        LOGGER.error('Directory %s already exists!', dest)
+        LOGGER.error("Directory %s already exists!", dest)
         ctx.exit(1)
     LOGGER.debug('copying "%s" to "%s"', src, dest)
     shutil.copytree(str(src), str(dest))
@@ -61,6 +61,10 @@ def write_tfstate_template(dest):
     """
     LOGGER.debug('writing TfState as a YAML template to "%s"', dest)
     # TODO remove use of six.u when dripping python 2 support
-    dest.write_text(six.u(to_yaml(TfState('test',
-                                          CFNginContext({'namespace': 'test'}),
-                                          None).to_json())))
+    dest.write_text(
+        six.u(
+            to_yaml(
+                TfState("test", CFNginContext({"namespace": "test"}), None).to_json()
+            )
+        )
+    )
