@@ -4,6 +4,6 @@ from aws_cdk import core
 from hello.hello_stack import MyStack
 
 app = core.App()
-MyStack(app, 'runway-cdk-py-sample')
+MyStack(app, "runway-cdk-py-sample")
 
 app.synth()
