@@ -17,9 +17,11 @@ class TestXrefHandler(unittest.TestCase):
     def test_xref_handler(self):
         """Test xref handler."""
         self.provider.get_output.return_value = "Test Output"
-        value = XrefLookup.handle("fully-qualified-stack-name::SomeOutput",
-                                  provider=self.provider,
-                                  context=self.context)
+        value = XrefLookup.handle(
+            "fully-qualified-stack-name::SomeOutput",
+            provider=self.provider,
+            context=self.context,
+        )
         self.assertEqual(value, "Test Output")
         self.assertEqual(self.context.get_fqn.call_count, 0)
         args = self.provider.get_output.call_args
