@@ -56,12 +56,12 @@ class TestStep(unittest.TestCase):
 
         self.assertNotEqual(self.step.status, True)
         self.assertNotEqual(self.step.status, False)
-        self.assertNotEqual(self.step.status, 'banana')
+        self.assertNotEqual(self.step.status, "banana")
 
     def test_from_stack_name(self):
         """Return step from step name."""
         context = mock_context()
-        stack_name = 'test-stack'
+        stack_name = "test-stack"
         result = Step.from_stack_name(stack_name, context)
 
         self.assertIsInstance(result, Step)
@@ -70,10 +70,7 @@ class TestStep(unittest.TestCase):
     def test_from_persistent_graph(self):
         """Return list of steps from graph dict."""
         context = mock_context()
-        graph_dict = {
-            'stack1': [],
-            'stack2': ['stack1']
-        }
+        graph_dict = {"stack1": [], "stack2": ["stack1"]}
         result = Step.from_persistent_graph(graph_dict, context)
 
         self.assertEqual(2, len(result))
@@ -90,16 +87,9 @@ class TestGraph(unittest.TestCase):
     def setUp(self):
         """Run before tests."""
         self.context = mock_context()
-        self.graph_dict = {
-            'stack1': [],
-            'stack2': ['stack1']
-        }
-        self.graph_dict_expected = {
-            'stack1': set(),
-            'stack2': set(['stack1'])
-        }
-        self.steps = Step.from_persistent_graph(self.graph_dict,
-                                                self.context)
+        self.graph_dict = {"stack1": [], "stack2": ["stack1"]}
+        self.graph_dict_expected = {"stack1": set(), "stack2": set(["stack1"])}
+        self.steps = Step.from_persistent_graph(self.graph_dict, self.context)
 
     def test_add_steps(self):
         """Test add steps."""
@@ -107,8 +97,7 @@ class TestGraph(unittest.TestCase):
         graph.add_steps(self.steps)
 
         self.assertEqual(self.steps, list(graph.steps.values()))
-        self.assertEqual([step.name for step in self.steps],
-                         list(graph.steps.keys()))
+        self.assertEqual([step.name for step in self.steps], list(graph.steps.keys()))
         self.assertEqual(self.graph_dict_expected, graph.to_dict())
 
     def test_pop(self):
@@ -116,10 +105,10 @@ class TestGraph(unittest.TestCase):
         graph = Graph()
         graph.add_steps(self.steps)
 
-        stack2 = next(step for step in self.steps if step.name == 'stack2')
+        stack2 = next(step for step in self.steps if step.name == "stack2")
 
         self.assertEqual(stack2, graph.pop(stack2))
-        self.assertEqual({'stack1': set()}, graph.to_dict())
+        self.assertEqual({"stack1": set()}, graph.to_dict())
 
     def test_dumps(self):
         """Test dumps."""
@@ -133,8 +122,7 @@ class TestGraph(unittest.TestCase):
         graph = Graph.from_dict(self.graph_dict, self.context)
 
         self.assertIsInstance(graph, Graph)
-        self.assertEqual([step.name for step in self.steps],
-                         list(graph.steps.keys()))
+        self.assertEqual([step.name for step in self.steps], list(graph.steps.keys()))
         self.assertEqual(self.graph_dict_expected, graph.to_dict())
 
     def test_from_steps(self):
@@ -142,8 +130,7 @@ class TestGraph(unittest.TestCase):
         graph = Graph.from_steps(self.steps)
 
         self.assertEqual(self.steps, list(graph.steps.values()))
-        self.assertEqual([step.name for step in self.steps],
-                         list(graph.steps.keys()))
+        self.assertEqual([step.name for step in self.steps], list(graph.steps.keys()))
         self.assertEqual(self.graph_dict_expected, graph.to_dict())
 
 
@@ -163,45 +150,42 @@ class TestPlan(unittest.TestCase):
 
     def test_plan(self):
         """Test plan."""
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=self.context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=self.context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
-            context=self.context)
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
+            context=self.context,
+        )
 
         graph = Graph.from_steps([Step(vpc, fn=None), Step(bastion, fn=None)])
         plan = Plan(description="Test", graph=graph)
 
-        self.assertEqual(plan.graph.to_dict(), {
-            'bastion.1': set(['vpc.1']),
-            'vpc.1': set([])})
+        self.assertEqual(
+            plan.graph.to_dict(), {"bastion.1": set(["vpc.1"]), "vpc.1": set([])}
+        )
 
     def test_plan_reverse(self):
         """Test plan reverse."""
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=self.context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=self.context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
-            context=self.context)
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
+            context=self.context,
+        )
         graph = Graph.from_steps([Step(vpc, fn=None), Step(bastion, fn=None)])
         plan = Plan(description="Test", graph=graph, reverse=True)
 
         # order is different between python2/3 so can't compare dicts
         result_graph_dict = plan.graph.to_dict()
-        self.assertEqual(set(), result_graph_dict.get('bastion.1'))
-        self.assertEqual(set(['bastion.1']), result_graph_dict.get('vpc.1'))
+        self.assertEqual(set(), result_graph_dict.get("bastion.1"))
+        self.assertEqual(set(["bastion.1"]), result_graph_dict.get("vpc.1"))
 
     def test_plan_targeted(self):
         """Test plan targeted."""
         context = Context(config=self.config)
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
-            context=context)
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
+            context=context,
+        )
         context.stack_names = [vpc.name]
         graph = Graph.from_steps([Step(vpc, fn=None), Step(bastion, fn=None)])
         plan = Plan(description="Test", graph=graph, context=context)
@@ -212,15 +196,14 @@ class TestPlan(unittest.TestCase):
         """Test execute plan."""
         context = Context(config=self.config)
         context.put_persistent_graph = mock.MagicMock()
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
-            context=context)
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
+            context=context,
+        )
         removed = Stack(
-            definition=generate_definition('removed', 1, requires=[]),
-            context=context)
+            definition=generate_definition("removed", 1, requires=[]), context=context
+        )
         context._persistent_graph = Graph.from_steps([removed])
 
         calls = []
@@ -233,36 +216,39 @@ class TestPlan(unittest.TestCase):
             calls.append(stack.fqn)
             return COMPLETE
 
-        graph = Graph.from_steps([Step(removed, _destroy_stack),
-                                  Step(vpc, _launch_stack),
-                                  Step(bastion, _launch_stack)])
+        graph = Graph.from_steps(
+            [
+                Step(removed, _destroy_stack),
+                Step(vpc, _launch_stack),
+                Step(bastion, _launch_stack),
+            ]
+        )
         plan = Plan(description="Test", graph=graph, context=context)
         plan.context._persistent_graph_lock_code = plan.lock_code
         plan.execute(walk)
 
         # the order these are appended changes between python2/3
-        self.assertIn('namespace-vpc.1', calls)
-        self.assertIn('namespace-bastion.1', calls)
-        self.assertIn('namespace-removed.1', calls)
+        self.assertIn("namespace-vpc.1", calls)
+        self.assertIn("namespace-bastion.1", calls)
+        self.assertIn("namespace-removed.1", calls)
         context.put_persistent_graph.assert_called()
 
         # order is different between python2/3 so can't compare dicts
         result_graph_dict = context.persistent_graph.to_dict()
         self.assertEqual(2, len(result_graph_dict))
-        self.assertEqual(set(), result_graph_dict.get('vpc.1'))
-        self.assertEqual(set(['vpc.1']), result_graph_dict.get('bastion.1'))
-        self.assertIsNone(result_graph_dict.get('namespace-removed.1'))
+        self.assertEqual(set(), result_graph_dict.get("vpc.1"))
+        self.assertEqual(set(["vpc.1"]), result_graph_dict.get("bastion.1"))
+        self.assertIsNone(result_graph_dict.get("namespace-removed.1"))
 
     def test_execute_plan_no_persist(self):
         """Test execute plan with no persistent graph."""
         context = Context(config=self.config)
         context.put_persistent_graph = mock.MagicMock()
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
-            context=context)
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
+            context=context,
+        )
 
         calls = []
 
@@ -270,13 +256,14 @@ class TestPlan(unittest.TestCase):
             calls.append(stack.fqn)
             return COMPLETE
 
-        graph = Graph.from_steps([Step(vpc, _launch_stack),
-                                  Step(bastion, _launch_stack)])
+        graph = Graph.from_steps(
+            [Step(vpc, _launch_stack), Step(bastion, _launch_stack)]
+        )
         plan = Plan(description="Test", graph=graph, context=context)
 
         plan.execute(walk)
 
-        self.assertEqual(calls, ['namespace-vpc.1', 'namespace-bastion.1'])
+        self.assertEqual(calls, ["namespace-vpc.1", "namespace-bastion.1"])
         context.put_persistent_graph.assert_not_called()
 
     def test_execute_plan_locked(self):
@@ -286,13 +273,12 @@ class TestPlan(unittest.TestCase):
         they're being created.
 
         """
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=self.context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=self.context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
             locked=True,
-            context=self.context)
+            context=self.context,
+        )
 
         calls = []
 
@@ -304,19 +290,19 @@ class TestPlan(unittest.TestCase):
         plan = Plan(description="Test", graph=graph)
         plan.execute(walk)
 
-        self.assertEqual(calls, ['namespace-vpc.1', 'namespace-bastion.1'])
+        self.assertEqual(calls, ["namespace-vpc.1", "namespace-bastion.1"])
 
     def test_execute_plan_filtered(self):
         """Test execute plan filtered."""
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=self.context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=self.context)
         db = Stack(
-            definition=generate_definition('db', 1, requires=[vpc.name]),
-            context=self.context)
+            definition=generate_definition("db", 1, requires=[vpc.name]),
+            context=self.context,
+        )
         app = Stack(
-            definition=generate_definition('app', 1, requires=[db.name]),
-            context=self.context)
+            definition=generate_definition("app", 1, requires=[db.name]),
+            context=self.context,
+        )
 
         calls = []
 
@@ -326,32 +312,27 @@ class TestPlan(unittest.TestCase):
 
         context = mock.MagicMock()
         context.persistent_graph_locked = False
-        context.stack_names = ['db.1']
+        context.stack_names = ["db.1"]
         graph = Graph.from_steps([Step(vpc, fn), Step(db, fn), Step(app, fn)])
-        plan = Plan(
-            context=context,
-            description="Test",
-            graph=graph)
+        plan = Plan(context=context, description="Test", graph=graph)
         plan.execute(walk)
 
-        self.assertEqual(calls, [
-            'namespace-vpc.1', 'namespace-db.1'])
+        self.assertEqual(calls, ["namespace-vpc.1", "namespace-db.1"])
 
     def test_execute_plan_exception(self):
         """Test execute plan exception."""
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=self.context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=self.context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
-            context=self.context)
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
+            context=self.context,
+        )
 
         calls = []
 
         def fn(stack, status=None):
             calls.append(stack.fqn)
             if stack.name == vpc_step.name:
-                raise ValueError('Boom')
+                raise ValueError("Boom")
             return COMPLETE
 
         vpc_step = Step(vpc, fn)
@@ -363,17 +344,16 @@ class TestPlan(unittest.TestCase):
         with self.assertRaises(PlanFailed):
             plan.execute(walk)
 
-        self.assertEqual(calls, ['namespace-vpc.1'])
+        self.assertEqual(calls, ["namespace-vpc.1"])
         self.assertEqual(vpc_step.status, FAILED)
 
     def test_execute_plan_skipped(self):
         """Test execute plan skipped."""
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=self.context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=self.context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
-            context=self.context)
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
+            context=self.context,
+        )
 
         calls = []
 
@@ -390,19 +370,16 @@ class TestPlan(unittest.TestCase):
         plan = Plan(description="Test", graph=graph)
         plan.execute(walk)
 
-        self.assertEqual(calls, ['namespace-vpc.1', 'namespace-bastion.1'])
+        self.assertEqual(calls, ["namespace-vpc.1", "namespace-bastion.1"])
 
     def test_execute_plan_failed(self):
         """Test execute plan failed."""
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=self.context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=self.context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
-            context=self.context)
-        db = Stack(
-            definition=generate_definition('db', 1),
-            context=self.context)
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
+            context=self.context,
+        )
+        db = Stack(definition=generate_definition("db", 1), context=self.context)
 
         calls = []
 
@@ -423,16 +400,15 @@ class TestPlan(unittest.TestCase):
 
         calls.sort()
 
-        self.assertEqual(calls, ['namespace-db.1', 'namespace-vpc.1'])
+        self.assertEqual(calls, ["namespace-db.1", "namespace-vpc.1"])
 
     def test_execute_plan_cancelled(self):
         """Test execute plan cancelled."""
-        vpc = Stack(
-            definition=generate_definition('vpc', 1),
-            context=self.context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=self.context)
         bastion = Stack(
-            definition=generate_definition('bastion', 1, requires=[vpc.name]),
-            context=self.context)
+            definition=generate_definition("bastion", 1, requires=[vpc.name]),
+            context=self.context,
+        )
 
         calls = []
 
@@ -449,14 +425,14 @@ class TestPlan(unittest.TestCase):
         plan = Plan(description="Test", graph=graph)
         plan.execute(walk)
 
-        self.assertEqual(calls, ['namespace-vpc.1', 'namespace-bastion.1'])
+        self.assertEqual(calls, ["namespace-vpc.1", "namespace-bastion.1"])
 
     def test_execute_plan_graph_locked(self):
         """Test execute plan with locked persistent graph."""
         context = Context(config=self.config)
-        context._persistent_graph = Graph.from_dict({'stack1': []}, context)
-        context._persistent_graph_lock_code = '1111'
-        plan = Plan(description='Test', graph=Graph(), context=context)
+        context._persistent_graph = Graph.from_dict({"stack1": []}, context)
+        context._persistent_graph_lock_code = "1111"
+        plan = Plan(description="Test", graph=Graph(), context=context)
         print(plan.locked)
 
         with self.assertRaises(PersistentGraphLocked):
@@ -465,15 +441,14 @@ class TestPlan(unittest.TestCase):
     def test_build_graph_missing_dependency(self):
         """Test build graph missing dependency."""
         bastion = Stack(
-            definition=generate_definition(
-                'bastion', 1, requires=['vpc.1']),
-            context=self.context)
+            definition=generate_definition("bastion", 1, requires=["vpc.1"]),
+            context=self.context,
+        )
 
         with self.assertRaises(GraphError) as expected:
             Graph.from_steps([Step(bastion, None)])
         message_starts = (
-            "Error detected when adding 'vpc.1' "
-            "as a dependency of 'bastion.1':"
+            "Error detected when adding 'vpc.1' as a dependency of 'bastion.1':"
         )
         message_contains = "dependent node vpc.1 does not exist"
         self.assertTrue(str(expected.exception).startswith(message_starts))
@@ -481,24 +456,23 @@ class TestPlan(unittest.TestCase):
 
     def test_build_graph_cyclic_dependencies(self):
         """Test build graph cyclic dependencies."""
-        vpc = Stack(
-            definition=generate_definition(
-                'vpc', 1),
-            context=self.context)
+        vpc = Stack(definition=generate_definition("vpc", 1), context=self.context)
         db = Stack(
-            definition=generate_definition(
-                'db', 1, requires=['app.1']),
-            context=self.context)
+            definition=generate_definition("db", 1, requires=["app.1"]),
+            context=self.context,
+        )
         app = Stack(
-            definition=generate_definition(
-                'app', 1, requires=['db.1']),
-            context=self.context)
+            definition=generate_definition("app", 1, requires=["db.1"]),
+            context=self.context,
+        )
 
         with self.assertRaises(GraphError) as expected:
             Graph.from_steps([Step(vpc, None), Step(db, None), Step(app, None)])
-        message = ("Error detected when adding 'db.1' "
-                   "as a dependency of 'app.1': graph is "
-                   "not acyclic")
+        message = (
+            "Error detected when adding 'db.1' "
+            "as a dependency of 'app.1': graph is "
+            "not acyclic"
+        )
         self.assertEqual(str(expected.exception), message)
 
     def test_dump(self, *args):
@@ -518,8 +492,9 @@ class TestPlan(unittest.TestCase):
             }
 
             stack = Stack(
-                definition=generate_definition('vpc', i, **overrides),
-                context=self.context)
+                definition=generate_definition("vpc", i, **overrides),
+                context=self.context,
+            )
             requires = [stack.name]
 
             steps += [Step(stack, None)]
@@ -533,8 +508,8 @@ class TestPlan(unittest.TestCase):
 
             for step in plan.steps:
                 template_path = os.path.join(
-                    tmp_dir,
-                    stack_template_key_name(step.stack.blueprint))
+                    tmp_dir, stack_template_key_name(step.stack.blueprint)
+                )
                 self.assertTrue(os.path.isfile(template_path))
         finally:
             shutil.rmtree(tmp_dir)
